@@ -21,7 +21,7 @@ mod log_tests;
 mod memcxt_tests;
 mod name_tests;
 mod numeric_tests;
-mod pg_extern_args_tests;
+mod pg_extern_tests;
 mod pg_try_tests;
 mod pgbox_tests;
 mod postgres_type_tests;
